# Namespace com.docusign.connect@0.4.0

## Overview
- 9 concepts
- 5 enumerations
- 1 assets
- 0 participants
- 1 transactions
- 0 events
- 16 total declarations

## Imports
- org.accordproject.runtime@0.2.0.Request
- org.accordproject.binary@0.2.0.BinaryResource
- concerto@1.0.0.Concept
- concerto@1.0.0.Asset
- concerto@1.0.0.Transaction
- concerto@1.0.0.Participant
- concerto@1.0.0.Event

## Diagram
```mermaid
classDiagram
class `com.docusign.connect@0.4.0.EnvelopeStatusCode` {
<< enumeration>>
   + `Any`
   + `Voided`
   + `Created`
   + `Deleted`
   + `Sent`
   + `Delivered`
   + `Signed`
   + `Completed`
   + `Declined`
   + `TimedOut`
   + `Template`
   + `Processing`
}

class `com.docusign.connect@0.4.0.RecipientStatusCode` {
<< enumeration>>
   + `Created`
   + `Sent`
   + `Delivered`
   + `Signed`
   + `Declined`
   + `Completed`
   + `FaxPending`
   + `AutoResponded`
}

class `com.docusign.connect@0.4.0.TabTypeCode` {
<< enumeration>>
   + `InitialHere`
   + `SignHere`
   + `FullName`
   + `FirstName`
   + `LastName`
   + `EmailAddress`
   + `Company`
   + `Title`
   + `DateSigned`
   + `InitialHereOptional`
   + `EnvelopeID`
   + `Custom`
   + `SignerAttachment`
   + `SignHereOptional`
   + `Approve`
   + `Decline`
   + `SignerAttachmentOptional`
   + `DigitalSignature`
}

class `com.docusign.connect@0.4.0.CustomTabTypeCode` {
<< enumeration>>
   + `Text`
   + `Checkbox`
   + `Radio`
   + `List`
   + `Date`
   + `Number`
   + `SSN`
   + `ZIP5`
   + `ZIP5DASH4`
   + `Email`
   + `Note`
   + `Formula`
}

class `com.docusign.connect@0.4.0.DocumentType` {
<< enumeration>>
   + `Principal`
   + `CertificateOfCompletion`
   + `SignerAttachment`
}

class `com.docusign.connect@0.4.0.EnvelopeStatus` {
<< concept>>
   + `EnvelopeStatusCode` `status`
   + `String` `envelopeId`
   + `DateTime` `created`
   + `DateTime` `sent`
   + `DateTime` `delivered`
   + `DateTime` `signed`
   + `DateTime` `completed`
   + `DateTime` `declined`
   + `String` `email`
}

`com.docusign.connect@0.4.0.EnvelopeStatus` "1" *-- "1" `com.docusign.connect@0.4.0.EnvelopeStatusCode`
class `com.docusign.connect@0.4.0.Recipient` {
<< concept>>
   + `RecipientStatusCode` `status`
   + `String` `email`
   + `String` `userName`
   + `DateTime` `sent`
   + `DateTime` `delivered`
   + `DateTime` `signed`
   + `DateTime` `declined`
   + `String` `declineReason`
   + `TabStatus[]` `tabStatuses`
}

`com.docusign.connect@0.4.0.Recipient` "1" *-- "1" `com.docusign.connect@0.4.0.RecipientStatusCode`
`com.docusign.connect@0.4.0.Recipient` "1" *-- "*" `com.docusign.connect@0.4.0.TabStatus`
class `com.docusign.connect@0.4.0.CustomField` {
<< concept>>
   + `String` `name`
   + `String` `value`
}

class `com.docusign.connect@0.4.0.TabStatus` {
<< concept>>
   + `TabTypeCode` `tabType`
   + `String` `status`
   + `String` `tabLabel`
   + `String` `originalValue`
   + `DateTime` `signed`
   + `CustomTabTypeCode` `customTabType`
}

`com.docusign.connect@0.4.0.TabStatus` "1" *-- "1" `com.docusign.connect@0.4.0.TabTypeCode`
`com.docusign.connect@0.4.0.TabStatus` "1" *-- "1" `com.docusign.connect@0.4.0.CustomTabTypeCode`
class `com.docusign.connect@0.4.0.NumberTabStatus` {
<< concept>>
   + `String` `tabName`
   + `Double` `tabValue`
}

`com.docusign.connect@0.4.0.NumberTabStatus` --|> `com.docusign.connect@0.4.0.TabStatus`
class `com.docusign.connect@0.4.0.TextTabStatus` {
<< concept>>
   + `String` `tabName`
   + `String` `tabValue`
}

`com.docusign.connect@0.4.0.TextTabStatus` --|> `com.docusign.connect@0.4.0.TabStatus`
class `com.docusign.connect@0.4.0.DateTabStatus` {
<< concept>>
   + `String` `tabName`
   + `DateTime` `tabValue`
}

`com.docusign.connect@0.4.0.DateTabStatus` --|> `com.docusign.connect@0.4.0.TabStatus`
class `com.docusign.connect@0.4.0.BooleanTabStatus` {
<< concept>>
   + `String` `tabName`
   + `Boolean` `tabValue`
}

`com.docusign.connect@0.4.0.BooleanTabStatus` --|> `com.docusign.connect@0.4.0.TabStatus`
class `com.docusign.connect@0.4.0.ListTabStatus` {
<< concept>>
   + `String[]` `tabNames`
   + `String` `tabValue`
   + `String[]` `listValues`
   + `String` `listSelectedValue`
}

`com.docusign.connect@0.4.0.ListTabStatus` --|> `com.docusign.connect@0.4.0.TabStatus`
class `com.docusign.connect@0.4.0.Attachment` {
<< asset>>
   + `DocumentType` `docType`
}

`com.docusign.connect@0.4.0.Attachment` "1" *-- "1" `com.docusign.connect@0.4.0.DocumentType`
`com.docusign.connect@0.4.0.Attachment` --|> `org.accordproject.binary@0.2.0.BinaryResource`
class `com.docusign.connect@0.4.0.DocuSignEnvelopeInformation` {
<< transaction>>
   + `EnvelopeStatus` `envelopeStatus`
   + `Recipient[]` `recipients`
   + `CustomField[]` `customFields`
   + `Attachment[]` `attachments`
}

`com.docusign.connect@0.4.0.DocuSignEnvelopeInformation` "1" *-- "1" `com.docusign.connect@0.4.0.EnvelopeStatus`
`com.docusign.connect@0.4.0.DocuSignEnvelopeInformation` "1" *-- "*" `com.docusign.connect@0.4.0.Recipient`
`com.docusign.connect@0.4.0.DocuSignEnvelopeInformation` "1" *-- "*" `com.docusign.connect@0.4.0.CustomField`
`com.docusign.connect@0.4.0.DocuSignEnvelopeInformation` "1" *-- "*" `com.docusign.connect@0.4.0.Attachment`
`com.docusign.connect@0.4.0.DocuSignEnvelopeInformation` --|> `org.accordproject.runtime@0.2.0.Request`
```

# Namespace org.accordproject.contract@0.2.0

## Overview
- 0 concepts
- 0 enumerations
- 2 assets
- 0 participants
- 0 transactions
- 0 events
- 2 total declarations

## Imports
- concerto@1.0.0.Concept
- concerto@1.0.0.Asset
- concerto@1.0.0.Transaction
- concerto@1.0.0.Participant
- concerto@1.0.0.Event

## Diagram
```mermaid
classDiagram
class `org.accordproject.contract@0.2.0.Contract` {
<< asset>>
   + `String` `contractId`
}

class `org.accordproject.contract@0.2.0.Clause` {
<< asset>>
   + `String` `clauseId`
}

```

# Namespace org.accordproject.runtime@0.2.0

## Overview
- 0 concepts
- 0 enumerations
- 1 assets
- 0 participants
- 2 transactions
- 1 events
- 4 total declarations

## Imports
- org.accordproject.contract@0.2.0.Contract
- concerto@1.0.0.Concept
- concerto@1.0.0.Asset
- concerto@1.0.0.Transaction
- concerto@1.0.0.Participant
- concerto@1.0.0.Event

## Diagram
```mermaid
classDiagram
class `org.accordproject.runtime@0.2.0.Request`
<< transaction>> `org.accordproject.runtime@0.2.0.Request`

class `org.accordproject.runtime@0.2.0.Response`
<< transaction>> `org.accordproject.runtime@0.2.0.Response`

class `org.accordproject.runtime@0.2.0.Obligation` {
<< event>>
   + `String` `$identifier`
`org.accordproject.runtime@0.2.0.Obligation` "1" o-- "1" `org.accordproject.contract@0.2.0.Contract` : contract
`org.accordproject.runtime@0.2.0.Obligation` "1" o-- "1" `concerto@1.0.0.Participant` : promisor
`org.accordproject.runtime@0.2.0.Obligation` "1" o-- "1" `concerto@1.0.0.Participant` : promisee
   + `DateTime` `deadline`
}

`org.accordproject.runtime@0.2.0.Obligation` "1" o-- "1" `org.accordproject.contract@0.2.0.Contract` : contract
`org.accordproject.runtime@0.2.0.Obligation` "1" o-- "1" `concerto@1.0.0.Participant` : promisor
`org.accordproject.runtime@0.2.0.Obligation` "1" o-- "1" `concerto@1.0.0.Participant` : promisee
class `org.accordproject.runtime@0.2.0.State`
<< asset>> `org.accordproject.runtime@0.2.0.State`

```

# Namespace org.accordproject.binary@0.2.0

## Overview
- 0 concepts
- 0 enumerations
- 3 assets
- 0 participants
- 0 transactions
- 0 events
- 3 total declarations

## Imports
- concerto@1.0.0.Concept
- concerto@1.0.0.Asset
- concerto@1.0.0.Transaction
- concerto@1.0.0.Participant
- concerto@1.0.0.Event

## Diagram
```mermaid
classDiagram
class `org.accordproject.binary@0.2.0.BinaryResource` {
<< asset>>
   + `String` `identifier`
   + `String` `name`
   + `String` `mimeType`
   + `String` `encoding`
}

class `org.accordproject.binary@0.2.0.BinaryReference`
<< asset>> `org.accordproject.binary@0.2.0.BinaryReference`

`org.accordproject.binary@0.2.0.BinaryReference` --|> `org.accordproject.binary@0.2.0.BinaryResource`
class `org.accordproject.binary@0.2.0.BinaryFile` {
<< asset>>
   + `String` `content`
}

`org.accordproject.binary@0.2.0.BinaryFile` --|> `org.accordproject.binary@0.2.0.BinaryResource`
```

